@@ -27,6 +27,10 @@ pub struct CreateClaimReceiptCtx<'info> {
     system_program: Program<'info, System>,
 }
 
-pub fn handler(_ctx: Context<CreateClaimReceiptCtx>, _target: Pubkey) -> Result<()> {
+pub fn handler(ctx: Context<CreateClaimReceiptCtx>, target: Pubkey) -> Result<()> {
+    let claim_receipt = &mut ctx.accounts.claim_receipt;
+    claim_receipt.mint_count = ctx.accounts.token_manager.count;
+    claim_receipt.token_manager = ctx.accounts.token_manager.key();
+    claim_receipt.target = target;
     return Ok(())
 }
\ No newline at end of file
